@@ -1,5 +1,5 @@
 package App::JobLog::Log;
-$App::JobLog::Log::VERSION = '1.036';
+$App::JobLog::Log::VERSION = '1.037';
 # ABSTRACT: the code that lets us interact with the log
 
 
@@ -51,6 +51,11 @@ sub new {
 }
 
 
+sub lines {
+  [ shift->[IO]->getlines ];
+}
+
+
 sub all_taglines {
     my ($self) = @_;
 
@@ -813,7 +818,7 @@ App::JobLog::Log - the code that lets us interact with the log
 
 =head1 VERSION
 
-version 1.036
+version 1.037
 
 =head1 DESCRIPTION
 
@@ -832,23 +837,28 @@ if it does not yet exist, initializing the hidden job log directory in the
 process, which means creating the directory and the README file. It also opens
 an L<IO::All> object to read or modify the log with.
 
+=head2 lines
+
+A reference to the list of lines in the current log. This is useful chiefly
+for debugging.
+
 =head2 all_taglines
 
 C<all_taglines> returns a list of all lines in the log that may have tags.
 
 =head2 all_events
 
-C<all_events> processes the log as a stream, extracting all events and 
+C<all_events> processes the log as a stream, extracting all events and
 returning them as an array reference.
 
 =head2 all_notes
 
-C<all_notes> processes the log as a stream, extracting all notes and 
+C<all_notes> processes the log as a stream, extracting all notes and
 returning them as an array reference.
 
 =head2 validate
 
-C<validate> makes sure the log contains only valid lines, all events are 
+C<validate> makes sure the log contains only valid lines, all events are
 in chronological order, and every ending follows a beginning. Invalid lines
 are commented out and a warning is emitted. The number of errors found is
 returned.
@@ -881,7 +891,7 @@ C<reverse_iterator> returns a closure that allows you to iterate
 over the events in the log in reverse. Every time you call the closure
 it returns the next unvisited event.
 
-If you pass this method an optional argument, either a L<DateTime> or a 
+If you pass this method an optional argument, either a L<DateTime> or a
 L<App::JobLog::Log::Event>, it will iterate from the event beginning at or
 after this event or time.
 
